Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp	(revision 84276)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp	(revision 84277)
@@ -118,19 +118,19 @@
                     }
 
-                    /* Create profile instances table: */
-                    m_pAccountImageList = new QListWidget(m_pCntLocation);
-                    if (m_pAccountImageList)
+                    /* Create source image list: */
+                    m_pSourceImageList = new QListWidget(m_pCntLocation);
+                    if (m_pSourceImageList)
                     {
-                        const QFontMetrics fm(m_pAccountImageList->font());
+                        const QFontMetrics fm(m_pSourceImageList->font());
                         const int iFontWidth = fm.width('x');
                         const int iTotalWidth = 50 * iFontWidth;
                         const int iFontHeight = fm.height();
                         const int iTotalHeight = 4 * iFontHeight;
-                        m_pAccountImageList->setMinimumSize(QSize(iTotalWidth, iTotalHeight));
-                        //m_pAccountImageList->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
-                        m_pAccountImageList->setAlternatingRowColors(true);
+                        m_pSourceImageList->setMinimumSize(QSize(iTotalWidth, iTotalHeight));
+                        //m_pSourceImageList->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
+                        m_pSourceImageList->setAlternatingRowColors(true);
 
                         /* Add into layout: */
-                        m_pCloudContainerLayout->addWidget(m_pAccountImageList, 2, 0);
+                        m_pCloudContainerLayout->addWidget(m_pSourceImageList, 2, 0);
                     }
 
@@ -183,5 +183,5 @@
     connect(m_pAccountToolButton, &QIToolButton::clicked,
             this, &UIWizardNewCloudVMPageExpert::sltHandleAccountButtonClick);
-    connect(m_pAccountImageList, &QListWidget::currentRowChanged,
+    connect(m_pSourceImageList, &QListWidget::currentRowChanged,
             this, &UIWizardNewCloudVMPageExpert::sltHandleInstanceListChange);
 
@@ -316,10 +316,10 @@
 
     /* Make image list focused by default: */
-    m_pAccountImageList->setFocus();
+    m_pSourceImageList->setFocus();
 
     /* Refresh required settings: */
     populateAccounts();
     populateAccountProperties();
-    populateAccountImages();
+    populateSourceImages();
     populateFormProperties();
     refreshFormPropertiesTable();
@@ -331,5 +331,5 @@
     /* Refresh required settings: */
     populateAccountProperties();
-    populateAccountImages();
+    populateSourceImages();
     populateFormProperties();
     refreshFormPropertiesTable();

Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 84276)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 84277)
@@ -53,6 +53,6 @@
     , m_pAccountToolButton(0)
     , m_pAccountPropertyTable(0)
-    , m_pAccountImageLabel(0)
-    , m_pAccountImageList(0)
+    , m_pSourceImageLabel(0)
+    , m_pSourceImageList(0)
 {
 }
@@ -269,11 +269,11 @@
 }
 
-void UIWizardNewCloudVMPage1::populateAccountImages()
+void UIWizardNewCloudVMPage1::populateSourceImages()
 {
     /* Block signals while updating: */
-    m_pAccountImageList->blockSignals(true);
+    m_pSourceImageList->blockSignals(true);
 
     /* Clear list initially: */
-    m_pAccountImageList->clear();
+    m_pSourceImageList->clear();
     /* Clear Cloud Client: */
     setClient(CCloudClient());
@@ -326,5 +326,5 @@
             {
                 /* Create list item: */
-                QListWidgetItem *pItem = new QListWidgetItem(names.at(i), m_pAccountImageList);
+                QListWidgetItem *pItem = new QListWidgetItem(names.at(i), m_pSourceImageList);
                 if (pItem)
                 {
@@ -335,6 +335,6 @@
 
             /* Choose the 1st one by default if possible: */
-            if (m_pAccountImageList->count())
-                m_pAccountImageList->setCurrentRow(0);
+            if (m_pSourceImageList->count())
+                m_pSourceImageList->setCurrentRow(0);
         }
         while (0);
@@ -342,5 +342,5 @@
 
     /* Unblock signals after update: */
-    m_pAccountImageList->blockSignals(false);
+    m_pSourceImageList->blockSignals(false);
 }
 
@@ -475,5 +475,5 @@
 QString UIWizardNewCloudVMPage1::imageId() const
 {
-    QListWidgetItem *pItem = m_pAccountImageList->currentItem();
+    QListWidgetItem *pItem = m_pSourceImageList->currentItem();
     return pItem ? pItem->data(Qt::UserRole).toString() : QString();
 }
@@ -584,9 +584,9 @@
             }
             /* Create sub-layout: */
-            QHBoxLayout *pSubLayout = new QHBoxLayout;
-            if (pSubLayout)
-            {
-                pSubLayout->setContentsMargins(0, 0, 0, 0);
-                pSubLayout->setSpacing(1);
+            QHBoxLayout *pAccountLayout = new QHBoxLayout;
+            if (pAccountLayout)
+            {
+                pAccountLayout->setContentsMargins(0, 0, 0, 0);
+                pAccountLayout->setSpacing(1);
 
                 /* Create account combo-box: */
@@ -597,5 +597,5 @@
 
                     /* Add into layout: */
-                    pSubLayout->addWidget(m_pAccountComboBox);
+                    pAccountLayout->addWidget(m_pAccountComboBox);
                 }
                 /* Create account tool-button: */
@@ -607,9 +607,9 @@
 
                     /* Add into layout: */
-                    pSubLayout->addWidget(m_pAccountToolButton);
+                    pAccountLayout->addWidget(m_pAccountToolButton);
                 }
 
                 /* Add into layout: */
-                m_pCloudContainerLayout->addLayout(pSubLayout, 0, 1);
+                m_pCloudContainerLayout->addLayout(pAccountLayout, 0, 1);
             }
 
@@ -634,27 +634,27 @@
             }
 
-            /* Create account instance label: */
-            m_pAccountImageLabel = new QLabel(this);
-            if (m_pAccountImageLabel)
+            /* Create source image label: */
+            m_pSourceImageLabel = new QLabel(this);
+            if (m_pSourceImageLabel)
             {
                 /* Add into layout: */
-                m_pCloudContainerLayout->addWidget(m_pAccountImageLabel, 2, 0, Qt::AlignRight);
-            }
-            /* Create profile instances table: */
-            m_pAccountImageList = new QListWidget(this);
-            if (m_pAccountImageList)
-            {
-                m_pAccountImageLabel->setBuddy(m_pAccountImageLabel);
-                const QFontMetrics fm(m_pAccountImageList->font());
+                m_pCloudContainerLayout->addWidget(m_pSourceImageLabel, 2, 0, Qt::AlignRight);
+            }
+            /* Create source image list: */
+            m_pSourceImageList = new QListWidget(this);
+            if (m_pSourceImageList)
+            {
+                m_pSourceImageLabel->setBuddy(m_pSourceImageList);
+                const QFontMetrics fm(m_pSourceImageList->font());
                 const int iFontWidth = fm.width('x');
                 const int iTotalWidth = 50 * iFontWidth;
                 const int iFontHeight = fm.height();
                 const int iTotalHeight = 4 * iFontHeight;
-                m_pAccountImageList->setMinimumSize(QSize(iTotalWidth, iTotalHeight));
-                //m_pAccountImageList->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
-                m_pAccountImageList->setAlternatingRowColors(true);
+                m_pSourceImageList->setMinimumSize(QSize(iTotalWidth, iTotalHeight));
+                //m_pSourceImageList->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
+                m_pSourceImageList->setAlternatingRowColors(true);
 
                 /* Add into layout: */
-                m_pCloudContainerLayout->addWidget(m_pAccountImageList, 2, 1, 2, 1);
+                m_pCloudContainerLayout->addWidget(m_pSourceImageList, 2, 1, 2, 1);
             }
 
@@ -674,5 +674,5 @@
     connect(m_pAccountToolButton, &QIToolButton::clicked,
             this, &UIWizardNewCloudVMPageBasic1::sltHandleAccountButtonClick);
-    connect(m_pAccountImageList, &QListWidget::currentRowChanged,
+    connect(m_pSourceImageList, &QListWidget::currentRowChanged,
             this, &UIWizardNewCloudVMPageBasic1::completeChanged);
 
@@ -729,5 +729,5 @@
     /* Translate cloud stuff: */
     m_pAccountLabel->setText(UIWizardNewCloudVM::tr("&Account:"));
-    m_pAccountImageLabel->setText(UIWizardNewCloudVM::tr("&Images:"));
+    m_pSourceImageLabel->setText(UIWizardNewCloudVM::tr("&Source:"));
 
     /* Adjust label widths: */
@@ -735,5 +735,5 @@
     labels << m_pLocationLabel;
     labels << m_pAccountLabel;
-    labels << m_pAccountImageLabel;
+    labels << m_pSourceImageLabel;
     int iMaxWidth = 0;
     foreach (QWidget *pLabel, labels)
@@ -797,10 +797,10 @@
 
     /* Make image list focused by default: */
-    m_pAccountImageList->setFocus();
+    m_pSourceImageList->setFocus();
 
     /* Refresh required settings: */
     populateAccounts();
     populateAccountProperties();
-    populateAccountImages();
+    populateSourceImages();
     emit completeChanged();
 }
@@ -810,5 +810,5 @@
     /* Refresh required settings: */
     populateAccountProperties();
-    populateAccountImages();
+    populateSourceImages();
     emit completeChanged();
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h	(revision 84276)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h	(revision 84277)
@@ -71,6 +71,6 @@
     /** Populates account properties. */
     void populateAccountProperties();
-    /** Populates account images. */
-    void populateAccountImages();
+    /** Populates source images. */
+    void populateSourceImages();
     /** Populates form properties. */
     void populateFormProperties();
@@ -137,8 +137,8 @@
     /** Holds the account property table instance. */
     QTableWidget *m_pAccountPropertyTable;
-    /** Holds the account image label instance. */
-    QLabel       *m_pAccountImageLabel;
-    /** Holds the account image list instance. */
-    QListWidget  *m_pAccountImageList;
+    /** Holds the source image label instance. */
+    QLabel       *m_pSourceImageLabel;
+    /** Holds the source image list instance. */
+    QListWidget  *m_pSourceImageList;
 };
 